@@ -6,19 +6,11 @@ use serde_json;
 use serde_json::Value;
 
 use jsontypes::RawSourceMap;
-use types::{RawToken, Token, SourceMap, SourceMapIndex, SourceMapSection};
+use types::{RawToken, SourceMap, SourceMapIndex, SourceMapSection, DecodedMap};
 use errors::{Result, Error};
+use vlq::parse_vlq_segment;
 
 const DATA_PREABLE: &'static str = "data:application/json;base64,";
-const B64: [i8; 123] = [
-    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-    -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, -1, 63, 52, 53, 54, 55, 56, 57,
-    58, 59, 60, 61, -1, -1, -1, -1, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8,
-    9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1,
-    -1, -1, -1, -1, -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38,
-    39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51
-];
 
 #[derive(PartialEq)]
 enum HeaderState {
@@ -128,62 +120,6 @@ fn strip_junk_header(slice: &[u8]) -> io::Result<&[u8]> {
     Ok(&slice[slice.len()..])
 }
 
-pub fn parse_vlq_segment(segment: &str) -> Result<Vec<i64>> {
-    let mut rv = vec![];
-
-    let mut cur = 0;
-    let mut shift = 0;
-
-    for c in segment.bytes() {
-        let enc = B64[c as usize] as i64;
-        let val = enc & 0b11111;
-        let cont = enc >> 5;
-        cur += val << shift;
-        shift += 5;
-
-        if cont == 0 {
-            let sign = cur & 1;
-            cur = cur >> 1;
-            if sign != 0 {
-                cur = -cur;
-            }
-            rv.push(cur);
-            cur = 0;
-            shift = 0;
-        }
-    }
-
-    if cur != 0 || shift != 0 {
-        Err(Error::VlqLeftover)
-    } else if rv.len() == 0 {
-        Err(Error::VlqNoValues)
-    } else {
-        Ok(rv)
-    }
-}
-
-/// Represents the result of a decode operation
-pub enum DecodedMap {
-    /// Indicates a regular sourcemap
-    Regular(SourceMap),
-    /// Indicates a sourcemap index
-    Index(SourceMapIndex),
-}
-
-impl DecodedMap {
-
-    /// Shortcut to look up a token on either an index or a
-    /// regular sourcemap.  This method can only be used if
-    /// the contained index actually contains embedded maps
-    /// or it will not be able to look up anything.
-    pub fn lookup_token<'a>(&'a self, line: u32, col: u32) -> Option<Token<'a>> {
-        match *self {
-            DecodedMap::Regular(ref sm) => sm.lookup_token(line, col),
-            DecodedMap::Index(ref smi) => smi.lookup_token(line, col),
-        }
-    }
-}
-
 fn decode_regular(rsm: RawSourceMap) -> Result<SourceMap> {
     let mut dst_col;
     let mut src_id = 0;
@@ -196,11 +132,8 @@ fn decode_regular(rsm: RawSourceMap) -> Result<SourceMap> {
     let mappings = rsm.mappings.unwrap_or_else(|| "".into());
     let allocation_size = mappings.matches(&[',', ';'][..]).count() + 10;
     let mut tokens = Vec::with_capacity(allocation_size);
-    let mut index = Vec::with_capacity(allocation_size);
-    let mut line_index = vec![];
 
     for (dst_line, line) in mappings.split(';').enumerate() {
-        line_index.clear();
         dst_col = 0;
 
         for segment in line.split(',') {
@@ -244,12 +177,6 @@ fn decode_regular(rsm: RawSourceMap) -> Result<SourceMap> {
                 src_id: src,
                 name_id: name,
             });
-            line_index.push((dst_col, (tokens.len() - 1) as u32));
-        }
-
-        line_index.sort();
-        for &(dst_col, token_id) in &line_index {
-            index.push((dst_line as u32, dst_col, token_id));
         }
     }
 
@@ -286,9 +213,7 @@ fn decode_regular(rsm: RawSourceMap) -> Result<SourceMap> {
         }
     });
 
-    Ok(SourceMap::new(
-        rsm.version.unwrap_or(0), file, tokens, index, names, sources,
-        rsm.sources_content))
+    Ok(SourceMap::new(file, tokens, names, sources, rsm.sources_content))
 }
 
 fn decode_index(rsm: RawSourceMap) -> Result<SourceMapIndex> {
@@ -315,8 +240,7 @@ fn decode_index(rsm: RawSourceMap) -> Result<SourceMapIndex> {
         }
     });
 
-    Ok(SourceMapIndex::new(
-        rsm.version.unwrap_or(0), file, sections))
+    Ok(SourceMapIndex::new(file, sections))
 }
 
 fn decode_common(rsm: RawSourceMap) -> Result<DecodedMap> {
@@ -348,7 +272,7 @@ pub fn decode_slice(slice: &[u8]) -> Result<DecodedMap> {
     decode_common(rsm)
 }
 
-/// Loads a sourcemap from a data URL.
+/// Loads a sourcemap from a data URL
 pub fn decode_data_url(url: &str) -> Result<DecodedMap> {
     if !url.starts_with(DATA_PREABLE) {
         fail!(Error::InvalidDataUrl);
