@@ -46,22 +46,29 @@ extern crate serde_derive;
 extern crate base64;
 extern crate serde;
 extern crate serde_json;
+extern crate url;
 
 mod macros;
 
 pub use types::{RawToken, Token, TokenIter, SourceMap, SourceMapIndex,
-                SourceMapSection, SourceMapSectionIter};
+                SourceMapSection, SourceMapSectionIter, RewriteOptions,
+                DecodedMap};
+pub use builder::SourceMapBuilder;
 pub use errors::{Result, Error};
-pub use decoder::{decode, decode_slice, decode_data_url, DecodedMap};
+pub use decoder::{decode, decode_slice, decode_data_url};
 pub use detector::{SourceMapRef, locate_sourcemap_reference};
 
+mod builder;
 mod errors;
 mod types;
 mod jsontypes;
 mod decoder;
+mod encoder;
 mod detector;
+mod vlq;
 
 #[doc(hidden)]
 pub mod internals {
     pub use super::decoder::StripHeaderReader;
+    pub use vlq::{parse_vlq_segment, generate_vlq_segment};
 }
